==> ecp_sync_plugin-6.8.6.tar.gz: android/src/main/java/ecp/vcs/com/ecpsyncplugin/re_sync/utils/DownloadFileFromURL.java <==
package ecp.vcs.com.ecpsyncplugin.re_sync.utils;

import android.app.ProgressDialog;
import android.content.Context;
import android.os.AsyncTask;
import android.util.Log;

import net.lingala.zip4j.core.ZipFile;
import net.lingala.zip4j.exception.ZipException;

import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;
import java.text.DecimalFormat;

import ecp.vcs.com.ecpsyncplugin.re_sync.SynchronizationService;
import ecp.vcs.com.ecpsyncplugin.re_sync.interfaces.FileDownload;
import ecp.vcs.com.ecpsyncplugin.re_sync.logging.LogHelper;
import ecp.vcs.com.ecpsyncplugin.re_sync.networking.AppUtil;
import ecp.vcs.com.ecpsyncplugin.re_sync.storage.ScopedStorage;


/**
 * Created by vcsdev0131 on 10/24/2017.
 */

public class DownloadFileFromURL extends AsyncTask<String, String, String> {

    private final Context context;
    private final String downloadFileName;
    private final FileDownload fileDownload;
    public static String parentpath ="";
//    public static String txtFileReadPath = Environment.getExternalStorageDirectory().toString() + "/RE_CPM_UPLOAD_TXT_FILE/";
    private boolean manualDownload = false;
    private ProgressDialog pDialog;
    private int hideLoader = 1;
    private String sync_type="";

    public DownloadFileFromURL(Context context, String downloadFileName, FileDownload fileDownload) {
        this.context = context;
        this.downloadFileName = downloadFileName;
        this.fileDownload = fileDownload;
        parentpath = ScopedStorage.getInstance(context).getPath(ScopedStorage.EXTERNAL_STORAGE_SYNC_RESPONSE_DEV)+"/";
    }
    public DownloadFileFromURL(Context context, String downloadFileName, FileDownload fileDownload, String sync_type) {
        this.context = context;
        this.downloadFileName = downloadFileName;
        this.fileDownload = fileDownload;
        this.sync_type = sync_type;
        parentpath = ScopedStorage.getInstance(context).getPath(ScopedStorage.EXTERNAL_STORAGE_SYNC_RESPONSE_DEV)+"/";
    }

    public DownloadFileFromURL(Context context, String downloadFileName, FileDownload fileDownload, String parentPath, int hideloader) {
        this.context = context;
        this.downloadFileName = downloadFileName;
        this.fileDownload = fileDownload;
        parentpath = parentPath;
        this.manualDownload = true;
        this.hideLoader = hideloader;
    }

    public DownloadFileFromURL(Context context, String downloadFileName, FileDownload fileDownload, String parentPath, boolean manualDownload) {
        this.context = context;
        this.downloadFileName = downloadFileName;
        this.fileDownload = fileDownload;
        parentpath = parentPath;
        this.manualDownload = manualDownload;
    }
    
    @Override
    protected void onProgressUpdate(String... progress) {
        Log.v("TAG_MANUAL",""+Integer.parseInt(progress[0])+"");
    }

    @Override
    protected String doInBackground(String... params) {
        try {
            // to delete all file from dir
            if (!manualDownload) {
                DeleteRecursive(new File(parentpath));
            }

            String fileDownloadUrl = params[0];
            int TIMEOUT_CONNECTION = 1800000;//30 mins
            int TIMEOUT_SOCKET = 1800000;//30 mins

            File myDir = new File(parentpath);
            if (!myDir.exists()) {
                myDir.mkdirs();
            } else {
                if (!manualDownload) {
                    deleteAllFiles(myDir);
                }
            }
            URL url = new URL(fileDownloadUrl);
            Log.i("image download ", fileDownloadUrl);
            //Open a connection to that URL.
            URLConnection ucon;
            try {
                ucon = url.openConnection();
            } catch (IOException e) {
                e.printStackTrace();
                SynchronizationService.isSuccess = false;
                SynchronizationService.exceptionDetails = AppUtil.getStackTrace(e);
                SynchronizationService.error_code = SyncErrorCode.SYNC_ERROR_151;
                return null;
            }

            //this timeout affects how long it takes for the app to realize there's a connection problem
            ucon.setReadTimeout(TIMEOUT_CONNECTION);
            ucon.setConnectTimeout(TIMEOUT_SOCKET);

            //Define InputStreams to read from the URLConnection.
            // uses 3KB download buffer
            InputStream is;
            try {
                is = ucon.getInputStream();
            } catch (Exception e) {
                SynchronizationService.isSuccess = false;
                SynchronizationService.exceptionDetails = AppUtil.getStackTrace(e);
                e.printStackTrace();
                SynchronizationService.error_code = SyncErrorCode.SYNC_ERROR_152;
                return null;
            }



            String size = getDownloadFileSize(ucon);



            Log.v("RECPM_FILESIZE", "Download File Size: " + size);
            LogHelper.printLog("TIME_forSync", "RECPM_FILESIZE" + size);



            String fname = downloadFileName + ".zip";

            File file = new File(myDir, fname);
            if (file.exists()) {
                File to = new File(file.getAbsolutePath() + System.currentTimeMillis());
                file.renameTo(to);
                to.delete();
            } else {

            }
//            BufferedInputStream inStream = new BufferedInputStream(is, 1024 * 5);
            BufferedInputStream inStream = new BufferedInputStream(is, 1024 * 1);
            FileOutputStream outStream;
            try {
                outStream = new FileOutputStream(file);
            } catch (Exception e) {
                SynchronizationService.isSuccess = false;
                SynchronizationService.exceptionDetails = AppUtil.getStackTrace(e);
                e.printStackTrace();
                SynchronizationService.error_code = SyncErrorCode.SYNC_ERROR_153;
                return null;
            }


            if (manualDownload){
                try {
                    int fileLength = ucon.getContentLength();
                    byte[] data = new byte[4096];
                    long total = 0;
                    int count;
                    while ((count = is.read(data)) != -1) {
                        // allow canceling with back button
                        if (isCancelled()) {
                            is.close();
                            return null;
                        }
                        total += count;
                        // publishing the progress....
                        if (fileLength > 0) // only if total length is known
                            publishProgress(""+(int) (total * 100 / fileLength));
                        outStream.write(data, 0, count);
                    }
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }else {
                byte[] buff = new byte[5 * 1024];
                int len;
                while ((len = inStream.read(buff)) != -1) {
                    outStream.write(buff, 0, len);
                }
            }



            outStream.flush();
            outStream.close();
            inStream.close();

//            Reading the Text File from the UnZipped File
            try {
//                if (manualDownload){
//                    ExtractAllFiles(parentpath + fname, parentpath);
//                }else {
//                    Content.setPreferenceValue(context, Const.downloadFilePath, downloadFileName);
//                    SynchronizationService.UnZIP_Start = System.currentTimeMillis();
//                    RetailerSellToFarmer.UnZIP_Start = System.currentTimeMillis();
//                    ExtractAllFiles(parentpath + fname, parentpath);
//                    File deleteZIP = new File(parentpath + fname);
//                    if (deleteZIP.exists())
//                        deleteZIP.delete();
//
//                    SynchronizationService.UnZIP_End = System.currentTimeMillis();
//                    RetailerSellToFarmer.UnZIP_End = System.currentTimeMillis();
//                }

                Content.setPreferenceValue(context, Const.downloadFilePath, downloadFileName);
                SynchronizationService.UnZIP_Start = System.currentTimeMillis();
//                SynchronizationService.UnZIP_Start = System.currentTimeMillis();
                ExtractAllFiles(parentpath + fname, parentpath);
                File deleteZIP = new File(parentpath + fname);
                if (deleteZIP.exists())
                    deleteZIP.delete();

                SynchronizationService.UnZIP_End = System.currentTimeMillis();
//                RetailerSellToFarmer.UnZIP_End = System.currentTimeMillis();


                return "true";
            } catch (Exception e) {
                SynchronizationService.isSuccess = false;
                SynchronizationService.exceptionDetails = AppUtil.getStackTrace(e);
                e.printStackTrace();
                SynchronizationService.error_code = SyncErrorCode.SYNC_ERROR_154;
            }

        } catch (Exception e) {
            SynchronizationService.isSuccess = false;
            SynchronizationService.exceptionDetails = AppUtil.getStackTrace(e);
            e.printStackTrace();
            SynchronizationService.error_code = SyncErrorCode.SYNC_ERROR_155;
        }
        return null;
    }


    @Override
    protected void onPostExecute(String response) {
        super.onPostExecute(response);
        if (response != null) {
            if (manualDownload) {
                fileDownload.onManualFileDownloadSuccess(response, hideLoader == 1);
            } else {
                fileDownload.onFileDownloadSuccess(response,sync_type);
            }
        } else {
            if (manualDownload) {
                fileDownload.onManualFileDownloadFailure();
            } else {
                fileDownload.onFileDownloadFailure();
            }
        }
        Log.e("TAG_SYNC FILE DOWNLOAD", "SYNC FILE DOWNLOADED SUCCESSFULLY");
    }

    public static String readTextFile(String readFilePath) {
//Get the text file
        File file = new File(readFilePath);

        if (file.exists()) {
//Read text from file
            StringBuilder text = new StringBuilder();
            try {
                BufferedReader br = new BufferedReader(new FileReader(file));
                String line;
                while ((line = br.readLine()) != null) {
                    text.append(line);
                    text.append('\n');
                }
                br.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
            if (text.length() > 0) {
                return text.toString();
            }
            return null;
        } else {
            return "file not found";
        }
    }

    private void deleteAllFiles(File root) {
        File[] files = root.listFiles();
        if (files != null && files.length > 0) {
            for (int i = 0; i < files.length; i++) {
                File myFile = files[i];
                if (myFile.exists())
                    myFile.delete();
            }
        }
    }

    public void ExtractAllFiles(String zipFileName, String Location) {

        try {
            // Initiate ZipFile object with the path/name of the zip file.
            ZipFile zipFile = new ZipFile(zipFileName);

            // Extracts all files to the path specified
            zipFile.extractAll(Location);

        } catch (ZipException e) {
            e.printStackTrace();
        }

    }

    public static void DeleteRecursive(File fileOrDirectory) {
        renameAndDelete(fileOrDirectory);
    }

    public static void renameAndDelete(File fileOrDirectory) {
        File newFile = new File(fileOrDirectory.getParent() + File.separator + "_" + fileOrDirectory.getName());
        fileOrDirectory.renameTo(newFile);
        delete(newFile);
    }

    public static void delete(File fileOrDirectory) {
        if (fileOrDirectory.isDirectory())
            for (File child : fileOrDirectory.listFiles())
                delete(child);

        fileOrDirectory.delete();
    }

    /**
     * Get Download File Size
     *
     * @param ucon
     * @return
     */
    private String getDownloadFileSize(URLConnection ucon) {
        try {
            int length = ucon.getContentLength();
            double kilobytes = ((double) length / 1024);
            DecimalFormat df = new DecimalFormat("#.##");
            String output = df.format(kilobytes);
            SynchronizationService.downloadFileSize = output;
            SynchronizationService.downloadFileSize = output;
            return output;
        } catch (Exception e) {
            SynchronizationService.isSuccess = false;
            SynchronizationService.exceptionDetails = e.getMessage();
            e.printStackTrace();
            return "";
        }
    }


}

==> ecp_sync_plugin-6.8.14.tar.gz: android/src/main/java/ecp/vcs/com/ecpsyncplugin/re_sync/utils/DownloadFileFromURL.java <==
package ecp.vcs.com.ecpsyncplugin.re_sync.utils;

import android.app.ProgressDialog;
import android.content.Context;
import android.os.AsyncTask;
import android.util.Log;

import net.lingala.zip4j.core.ZipFile;
import net.lingala.zip4j.exception.ZipException;

import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;
import java.text.DecimalFormat;

import ecp.vcs.com.ecpsyncplugin.re_sync.SynchronizationService;
import ecp.vcs.com.ecpsyncplugin.re_sync.interfaces.FileDownload;
import ecp.vcs.com.ecpsyncplugin.re_sync.logging.LogHelper;
import ecp.vcs.com.ecpsyncplugin.re_sync.networking.AppUtil;
import ecp.vcs.com.ecpsyncplugin.re_sync.storage.ScopedStorage;


/**
 * Created by vcsdev0131 on 10/24/2017.
 */

public class DownloadFileFromURL extends AsyncTask<String, String, String> {

    private final Context context;
    private final String downloadFileName;
    private final FileDownload fileDownload;
    public static String parentpath ="";
//    public static String txtFileReadPath = Environment.getExternalStorageDirectory().toString() + "/RE_CPM_UPLOAD_TXT_FILE/";
    private boolean manualDownload = false;
    private ProgressDialog pDialog;
    private int hideLoader = 1;
    private String sync_type="";

    public DownloadFileFromURL(Context context, String downloadFileName, FileDownload fileDownload) {
        this.context = context;
        this.downloadFileName = downloadFileName;
        this.fileDownload = fileDownload;
        parentpath = ScopedStorage.getInstance(context).getPath(ScopedStorage.EXTERNAL_STORAGE_SYNC_RESPONSE_DEV)+"/";
    }
    public DownloadFileFromURL(Context context, String downloadFileName, FileDownload fileDownload, String sync_type) {
        this.context = context;
        this.downloadFileName = downloadFileName;
        this.fileDownload = fileDownload;
        this.sync_type = sync_type;
        parentpath = ScopedStorage.getInstance(context).getPath(ScopedStorage.EXTERNAL_STORAGE_SYNC_RESPONSE_DEV)+"/";
    }

    public DownloadFileFromURL(Context context, String downloadFileName, FileDownload fileDownload, String parentPath, int hideloader) {
        this.context = context;
        this.downloadFileName = downloadFileName;
        this.fileDownload = fileDownload;
        parentpath = parentPath;
        this.manualDownload = true;
        this.hideLoader = hideloader;
    }

    public DownloadFileFromURL(Context context, String downloadFileName, FileDownload fileDownload, String parentPath, boolean manualDownload) {
        this.context = context;
        this.downloadFileName = downloadFileName;
        this.fileDownload = fileDownload;
        parentpath = parentPath;
        this.manualDownload = manualDownload;
    }
    
    @Override
    protected void onProgressUpdate(String... progress) {
        Log.v("TAG_MANUAL",""+Integer.parseInt(progress[0])+"");
    }

    @Override
    protected String doInBackground(String... params) {
        try {
            // to delete all file from dir
            if (!manualDownload) {
                DeleteRecursive(new File(parentpath));
            }

            String fileDownloadUrl = params[0];
            int TIMEOUT_CONNECTION = 1800000;//30 mins
            int TIMEOUT_SOCKET = 1800000;//30 mins

            File myDir = new File(parentpath);
            if (!myDir.exists()) {
                myDir.mkdirs();
            } else {
                if (!manualDownload) {
                    deleteAllFiles(myDir);
                }
            }
            URL url = new URL(fileDownloadUrl);
            Log.i("image download ", fileDownloadUrl);
            //Open a connection to that URL.
            URLConnection ucon;
            try {
                ucon = url.openConnection();
            } catch (IOException e) {
                e.printStackTrace();
                SynchronizationService.isSuccess = false;
                SynchronizationService.exceptionDetails = AppUtil.getStackTrace(e);
                SynchronizationService.error_code = SyncErrorCode.SYNC_ERROR_151;
                return null;
            }

            //this timeout affects how long it takes for the app to realize there's a connection problem
            ucon.setReadTimeout(TIMEOUT_CONNECTION);
            ucon.setConnectTimeout(TIMEOUT_SOCKET);

            //Define InputStreams to read from the URLConnection.
            // uses 3KB download buffer
            InputStream is;
            try {
                is = ucon.getInputStream();
            } catch (Exception e) {
                SynchronizationService.isSuccess = false;
                SynchronizationService.exceptionDetails = AppUtil.getStackTrace(e);
                e.printStackTrace();
                SynchronizationService.error_code = SyncErrorCode.SYNC_ERROR_152;
                return null;
            }



            String size = getDownloadFileSize(ucon);



            Log.v("RECPM_FILESIZE", "Download File Size: " + size);
            LogHelper.printLog("TIME_forSync", "RECPM_FILESIZE" + size);



            String fname = downloadFileName + ".zip";

            File file = new File(myDir, fname);
            if (file.exists()) {
                File to = new File(file.getAbsolutePath() + System.currentTimeMillis());
                file.renameTo(to);
                to.delete();
            } else {

            }
//            BufferedInputStream inStream = new BufferedInputStream(is, 1024 * 5);
            BufferedInputStream inStream = new BufferedInputStream(is, 1024 * 1);
            FileOutputStream outStream;
            try {
                outStream = new FileOutputStream(file);
            } catch (Exception e) {
                SynchronizationService.isSuccess = false;
                SynchronizationService.exceptionDetails = AppUtil.getStackTrace(e);
                e.printStackTrace();
                SynchronizationService.error_code = SyncErrorCode.SYNC_ERROR_153;
                return null;
            }


            if (manualDownload){
                try {
                    int fileLength = ucon.getContentLength();
                    byte[] data = new byte[4096];
                    long total = 0;
                    int count;
                    while ((count = is.read(data)) != -1) {
                        // allow canceling with back button
                        if (isCancelled()) {
                            is.close();
                            return null;
                        }
                        total += count;
                        // publishing the progress....
                        if (fileLength > 0) // only if total length is known
                            publishProgress(""+(int) (total * 100 / fileLength));
                        outStream.write(data, 0, count);
                    }
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }else {
                byte[] buff = new byte[5 * 1024];
                int len;
                while ((len = inStream.read(buff)) != -1) {
                    outStream.write(buff, 0, len);
                }
            }



            outStream.flush();
            outStream.close();
            inStream.close();

//            Reading the Text File from the UnZipped File
            try {
//                if (manualDownload){
//                    ExtractAllFiles(parentpath + fname, parentpath);
//                }else {
//                    Content.setPreferenceValue(context, Const.downloadFilePath, downloadFileName);
//                    SynchronizationService.UnZIP_Start = System.currentTimeMillis();
//                    RetailerSellToFarmer.UnZIP_Start = System.currentTimeMillis();
//                    ExtractAllFiles(parentpath + fname, parentpath);
//                    File deleteZIP = new File(parentpath + fname);
//                    if (deleteZIP.exists())
//                        deleteZIP.delete();
//
//                    SynchronizationService.UnZIP_End = System.currentTimeMillis();
//                    RetailerSellToFarmer.UnZIP_End = System.currentTimeMillis();
//                }

//                Content.setPreferenceValue(context, Const.downloadFilePath, downloadFileName);
                SynchronizationService.UnZIP_Start = System.currentTimeMillis();
//                SynchronizationService.UnZIP_Start = System.currentTimeMillis();
                ExtractAllFiles(parentpath + fname, parentpath);
                File deleteZIP = new File(parentpath + fname);
                if (deleteZIP.exists())
                    deleteZIP.delete();

                SynchronizationService.UnZIP_End = System.currentTimeMillis();
//                RetailerSellToFarmer.UnZIP_End = System.currentTimeMillis();


                return "true";
            } catch (Exception e) {
                SynchronizationService.isSuccess = false;
                SynchronizationService.exceptionDetails = AppUtil.getStackTrace(e);
                e.printStackTrace();
                SynchronizationService.error_code = SyncErrorCode.SYNC_ERROR_154;
            }

        } catch (Exception e) {
            SynchronizationService.isSuccess = false;
            SynchronizationService.exceptionDetails = AppUtil.getStackTrace(e);
            e.printStackTrace();
            SynchronizationService.error_code = SyncErrorCode.SYNC_ERROR_155;
        }
        return null;
    }


    @Override
    protected void onPostExecute(String response) {
        super.onPostExecute(response);
        if (response != null) {
            if (manualDownload) {
                fileDownload.onManualFileDownloadSuccess(response, hideLoader == 1);
            } else {
                fileDownload.onFileDownloadSuccess(response,sync_type);
            }
        } else {
            if (manualDownload) {
                fileDownload.onManualFileDownloadFailure();
            } else {
                fileDownload.onFileDownloadFailure();
            }
        }
        Log.e("TAG_SYNC FILE DOWNLOAD", "SYNC FILE DOWNLOADED SUCCESSFULLY");
    }

    public static String readTextFile(String readFilePath) {
//Get the text file
        File file = new File(readFilePath);

        if (file.exists()) {
//Read text from file
            StringBuilder text = new StringBuilder();
            try {
                BufferedReader br = new BufferedReader(new FileReader(file));
                String line;
                while ((line = br.readLine()) != null) {
                    text.append(line);
                    text.append('\n');
                }
                br.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
            if (text.length() > 0) {
                return text.toString();
            }
            return null;
        } else {
            return "file not found";
        }
    }

    private void deleteAllFiles(File root) {
        File[] files = root.listFiles();
        if (files != null && files.length > 0) {
            for (int i = 0; i < files.length; i++) {
                File myFile = files[i];
                if (myFile.exists())
                    myFile.delete();
            }
        }
    }

    public void ExtractAllFiles(String zipFileName, String Location) {

        try {
            // Initiate ZipFile object with the path/name of the zip file.
            ZipFile zipFile = new ZipFile(zipFileName);

            // Extracts all files to the path specified
            zipFile.extractAll(Location);

        } catch (ZipException e) {
            e.printStackTrace();
        }

    }

    public static void DeleteRecursive(File fileOrDirectory) {
        renameAndDelete(fileOrDirectory);
    }

    public static void renameAndDelete(File fileOrDirectory) {
        File newFile = new File(fileOrDirectory.getParent() + File.separator + "_" + fileOrDirectory.getName());
        fileOrDirectory.renameTo(newFile);
        delete(newFile);
    }

    public static void delete(File fileOrDirectory) {
        if (fileOrDirectory.isDirectory())
            for (File child : fileOrDirectory.listFiles())
                delete(child);

        fileOrDirectory.delete();
    }

    /**
     * Get Download File Size
     *
     * @param ucon
     * @return
     */
    private String getDownloadFileSize(URLConnection ucon) {
        try {
            int length = ucon.getContentLength();
            double kilobytes = ((double) length / 1024);
            DecimalFormat df = new DecimalFormat("#.##");
            String output = df.format(kilobytes);
            SynchronizationService.downloadFileSize = output;
            SynchronizationService.downloadFileSize = output;
            return output;
        } catch (Exception e) {
            SynchronizationService.isSuccess = false;
            SynchronizationService.exceptionDetails = e.getMessage();
            e.printStackTrace();
            return "";
        }
    }


}
